plumbery.fittings package
=========================

Submodules
----------

.. toctree::

   plumbery.fittings.dummy

Module contents
---------------

.. automodule:: plumbery.fittings
    :members:
    :undoc-members:
    :show-inheritance:
